<?php
/**
 * @package   DocImport
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

defined('_JEXEC') || die;

use Akeeba\Component\DocImport\Administrator\View\Articles\HtmlView;
use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Multilanguage;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Layout\LayoutHelper;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Session\Session;

/** @var HtmlView $this */

$app = Factory::getApplication();

if ($app->isClient('site')) {
	Session::checkToken('get') or die(Text::_('JINVALID_TOKEN'));
}

/** @var Joomla\CMS\WebAsset\WebAssetManager $wa */
$wa = $this->document->getWebAssetManager();
$wa->useScript('core')
	->useScript('multiselect')
	->useScript('com_docimport.modal');

$multilang = Multilanguage::isEnabled();
$editor    = $app->getInput()->getCmd('editor', '');

$this->document->addScriptOptions('xtd-docimport', ['editor' => $editor]);


$user      = Factory::getApplication()->getIdentity() ?: Factory::getUser();
$userId    = $user->get('id');
$listOrder = $this->escape($this->state->get('list.ordering'));
$listDirn  = $this->escape($this->state->get('list.direction'));
$saveOrder = $listOrder == 'ordering';
$nullDate  = Factory::getDbo()->getNullDate();

if ($saveOrder && !empty($this->items))
{
	$saveOrderingUrl = 'index.php?option=com_docimport&task=articles.saveOrderAjax&tmpl=component&' . Session::getFormToken() . '=1';
	HTMLHelper::_('draggablelist.draggable');
}

$i = 0;
?>
<div class="container-popup">
	<form action="<?= Route::_('index.php?option=com_docimport&view=articles&layout=modal&tmpl=component&editor=' . $editor); ?>"
	      method="post" name="adminForm" id="adminForm">

		<?= LayoutHelper::render('joomla.searchtools.default', ['view' => $this]) ?>

		<?php if (empty($this->items)) : ?>
			<div class="alert alert-info">
				<span class="icon-info-circle" aria-hidden="true"></span><span class="visually-hidden"><?= Text::_('INFO'); ?></span>
				<?= Text::_('JGLOBAL_NO_MATCHING_RESULTS'); ?>
			</div>
		<?php else : ?>
			<table class="table table-sm">
				<caption class="visually-hidden">
					<?= Text::_('COM_DOCIMPORT_ARTICLES_TABLE_CAPTION'); ?>,
					<span id="orderedBy"><?= Text::_('JGLOBAL_SORTED_BY'); ?> </span>,
					<span id="filteredBy"><?= Text::_('JGLOBAL_FILTERED_BY'); ?></span>
				</caption>
				<thead>
				<tr>
					<th scope="col" class="w-1 text-center">
						<?= HTMLHelper::_('searchtools.sort', 'JPUBLISHED', 'enabled', $listDirn, $listOrder) ?>
					</th>
					<th scope="col" class="title">
						<?= HTMLHelper::_('searchtools.sort', 'JGLOBAL_TITLE', 'title', $listDirn, $listOrder) ?>
					</th>
					<th scope="col" class="w-10 d-none d-md-table-cell">
						<?= HTMLHelper::_('searchtools.sort', 'JGRID_HEADING_ACCESS', 'access', $listDirn, $listOrder) ?>
					</th>
					<?php if ($multilang) : ?>
						<th scope="col" class="w-15">
							<?= HTMLHelper::_('searchtools.sort', 'JGRID_HEADING_LANGUAGE', 'language', $listDirn, $listOrder) ?>
						</th>
					<?php endif; ?>
					<th scope="col" class="w-1 d-none d-md-table-cell">
						<?= HTMLHelper::_('searchtools.sort', 'JGRID_HEADING_ID', 'docimport_article_id', $listDirn, $listOrder) ?>
					</th>
				</tr>
				</thead>
				<tbody <?php if ($saveOrder) :?> class="js-draggable" data-url="<?= $saveOrderingUrl ?>" data-direction="<?= strtolower($listDirn) ?>" data-nested="false"<?php endif; ?>>
				<?php foreach ($this->items as $item) :?>
					<tr class="row<?= $i++ % 2; ?>">
						<td class="text-center">
							<?php if($item->enabled): ?>
								<span class="tbody-icon">
									<span class="icon-check" aria-hidden="true"></span>
									<span class="visually-hidden"><?= Text::_('JPUBLISHED') ?></span>
								</span>
							<?php else: ?>
								<span class="tbody-icon">
									<span class="icon-times" aria-hidden="true"></span>
									<span class="visually-hidden"><?= Text::_('JUNPUBLISHED') ?></span>
								</span>
							<?php endif; ?>
						</td>
						<th scope="row">
							<?php
							$attribs = \Joomla\Utilities\ArrayHelper::toString([
								'data-id' => $item->docimport_article_id,
								'data-title' => $this->escape($item->title),
								'data-uri' => Route::_(
									sprintf(
										'index.php?option=com_docimport&view=article&catid=%d&id=%d',
										$item->docimport_category_id,
										$item->docimport_article_id,
									)
								)
							])
							?>
							<a class="select-link" href="javascript:void(0)" <?= $attribs ?>>
								<?= $this->escape($item->title)?>
							</a>
							<div class="small break-word">
								<?= Text::sprintf('JGLOBAL_LIST_ALIAS', $this->escape($item->slug)) ?>
							</div>
							<div class="small">
								<?= Text::_('JCATEGORY') . ': ' . $this->escape($item->cat_title) ?>
							</div>
						</th>
						<td class="small d-none d-md-table-cell">
							<?= $this->escape($item->access_level) ?>
						</td>
						<?php if ($multilang) : ?>
							<td class="small">
								<?= LayoutHelper::render('joomla.content.language', $item) ?>
							</td>
						<?php endif; ?>
						<td class="small d-none d-md-table-cell">
							<?php echo (int) $item->docimport_article_id; ?>
						</td>
					</tr>
				<?php endforeach; ?>
				</tbody>
			</table>

			<?php // Load the pagination. ?>
			<?= $this->pagination->getListFooter(); ?>
		<?php endif; ?>

		<input type="hidden" name="task" value="">
		<input type="hidden" name="boxchecked" value="0">
		<?= HTMLHelper::_('form.token'); ?>
	</form>
</div>
